==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/8b/8b9a56427805fec9021e00a93b403fb9.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PluginBundle/Assets/img/generic.png */
class __TwigTemplate_71080000c6b05399e6c9e33a4b7002d1 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000>a\000\000/IDATx]x^AEz{mbHЋ@@B{DHlIｇF3̖<ٝٙ9;Oeaaaaaaa2Y)9L^tQQpꬒc3NN)>2صχ{Td;V羦_SPWn<2h߅[]IY+\"y_rڬIlIJ㗔dGT!yOʿqI~_eQ-c]Kv\$ǌ\\\\.Nq,ui=\000<8x87o#[:?+\\?t:^Ub+Z^vυ;zqv\\pl#@Wk<Gw[t+c.}eaSYǳ35}vW]|8Nm΅;yNcB*\000֑}Kp'q~'#>Ӹo^Hy[eOo.x,<YS\"L;zrv`^9[`H#hxEwa.4.sn]*x
r?w:<X# m=9=!ʅ\000d qF!\t<A!&W_NY\\eOf]ѻ%ڜwil!\t^@7\000Å1`,DH\0002EWaJ\"M\\DȾ3=~UQ}W0da@3Hqr\t\\=\000F\$i;5[':Ĉ~s\"q-@6Dm\"Wꨴ?iF&~H::|f\tC
cӑ4\$,uA-~8ΐ-DAbPr_G׶'L@Ǵ]#v4<~r_Eb*h䙯O9ܷDޝ)\"]c@^ybf](t5cdmFq3q3a|5#Q\0008\000) .{/qFMJvXϥaGF_BLH>^!ax{ m\"71cWfĎ[\"_?n䠹\\쀹0satNw ^;ăE<΂\000^MVY/o&n~\$t9Ð zؾAw^lVqѣ^wp޳s7s=0}ǹ
N\\Kxp`|)KNZ3-{uɳ\"aꅑOvKOx@VSG,)In*o4/:wN9Ո6=CO`Z7f7jYm[:&g!]x\t7',ޞ6Oz=\"{[R\$\000|Pzln5̷Bmf[uG\$>l!MGuK~=nRHߚ{è|A31q\t}O+q*x_^|?FŇ,qW|ݼ%lT%(0{ʜ-Y=  =N8 \000@>.TѰQ0XgZ4vH4`Cg
Xn7/h'6>:e@kΛ.޼9,܋?`=3TQq5x<Bк~0vCAskXL).jٳg@ϿE\"H0yZ3\000pMBA/ClMy7=D]P0=/9hN\000{MWp\"K


?|&_Eɓ\$N2%aʔ\t'ON:uZU?]4%99]MtH:b
#;
'oܳSDMxPvA멲=疇fc'>/u.|4:۷˔){9::sqť#7p-[3u8s=z2'-粖=]MZ6ݤua<cj!.c}VVM]/ڵƏ/ڵ\tHv֍ԩ3ױήX^}nE>1V׶teD?5g}&
qA(줲,\$k8S0B`\000a?,<Ե vpr&wb;:ٝ\000on\000Bp:rjf\000UE\$D/-SʟFRD:1l,8?ƕSR\\`k}e2N\000r
%N^s#%?F9IA;f͎ppp-\"]\"\000\000\"pp֮]{\"!MGOaDx9.uO']|EeGWRV9t8G3x3q
<svxad;E4\$̙3spwgi{d`\$:<gu)0qM~\"%U5{Ͼs~?~|p߾}ws
%\000AD0rT(i&MX}GLB&L&ڨ佨s(;|Q&kJ.ɫoŧ\$FLL&NXu)z+n-qcǎQUrW#:Ɍ#ՄRY5=+@phF9\000t}ڲ]uoɯg׳gO )~@\\l!1J.SQ[[Bt>I=8)L*94SeǭH.c+T^ăꛭ8t=z\000LX_~x{+1Uff5SYrf:)g_R\000E\000yk|w]v%5\000NM\"A/x3|K+V06ne8hl)FoM]Ʋe.vYTc/8zqk֬٢/p\"\\C W;kӑ=y)FU;\ty)q%@\"`&+7w ċH\000֭ۨp^
gHR]W_?:C:=M|B|K2X/J}tŢ}h %_~wܩ:\\Z<^P@= ׬\t\"Fo
ќJ X;:ڬL֭|sH0.0x;aaa]
El==̑,>av؞*0>2nSؕ3P|\"
X#s\$G#f`X0U\"_I0; ;JtrO&^sr>PYQp>~( r5bDy
|'''\$`t:wv~M܀v4:r;N ƝܿAxA\\i*0>*2tnQXau4T4\\
rJG\tV|]믇%%%U.iQ~ξCr6;4ws2Gt7f\$gJ:*0=ʂ\">Ӵ\"V!+_ʄE&oM˰.;88U,̋Hn{We?@J][P`5988&dYM@s#mWoGGH1`zպ}jEZkoo/iכ899krW}4Pw4YZeG.N}<L
\t\\5/J\"^NڼEٯ<D\000%U#̵a@02%Px<YPH
::}o}3f\$wޝX9D}\000f?%3z3Vԣ*98#lA)G@#4hPSu,ЅR_ HvҤIwvtlll8[[Ζ # A
UYGӏl~j'vR
7
.\$b>M!B(ۦ.o=JZfLttkZe㦀O65fIܐ!C̙:vg;EŚvPA\000̗m8ch,'2܏թfӯS^?dg..*ԩSqeL\000A|poTЕ1;6`NB8w̥-C}'++덕+W^
|g YSYGӎۅK N0<7}bstr 0^Z~\t\000\\@RpX\000(رcUBE=pv:\\e
Zr͆%[?3]^^\" 0+ B6mZ:?RYGӏ>d',lE\000:q<tＹHaA(iG47.`6G\000\\Br{ؚ 킍 %V\$B8!u\"n }1mGsc,UǙMRP&N\$\t߼|rwu4*z;sZųeI<5FR?_;=,}3IM\$9qu~_Ph0%\$v:>owEMgX%Knu&R}wDݫWא.Ca\"GI:իWGɌ̿/XiCR#Z|8T
}\000Dч|&WKZD3]!
o`|Bk'5laBTcD퇸:LCdO&e7ȇ+C`?3i:~*(}=}WдYX܁t\000\000

 H?zY٭/V6m:,AAؼyRYĺIݺ(R@gKf\000+O:w!EDSYw++
;!!aÊ\$|޽{?駟BTp33_O#rdUH+Wسgd.C啴N1GCŤ{BC֕U8f?@
ێ
Et.rrҥL۵k5~]N\000ϟ|X0<
D.w~}f`<xpʴ԰𫯾zjnQy\"Ύ\\|A-C
bκSp*_<?~|V\"\"+\"KȬ^GI58=<ZND[R)t˫e!'pg>oGyv%B|8aX,K@>T;cmz.<Ӭ={߀+%p\000A)hD>8&#r;9gݾ}?Ąg7'L>=.RBfL%K\\)--m7w<U\\*b=voEMRVFMܹs \000hSE6Vr7PFro#l-jժx@
e3A<oBq_jM{B+6ZX\"r
u!Cc?gxxgxF!U(BYEƒL̦+SE5vݹ\${<u\tx\000q֛Jff
Z9{K2@Pu˫=c
6F!u&N\"\$q)'\000nː8(?=z5ǂ%=4#P]Cnnn/9Z\tea//!!y 7\\exzFuCf,&J3Z<q#`&}rai?
.f4\000hV73z}Wn'{mc4pؓЇ\\X'kZ5Ӝ`P[(\"\000B*Z5(,\\%sى0;;<\tڥFtF
ǍDY4n7r|ٵvEJº@փo\$繬69CZ7IpɛHSdMd¾XydVlX*AGCAg>k<!HԩPf^\\.{^3_Fu
x\000-\t-[@>'?wDw\\B2E\000~JM?w9P(deEB47N\0001c0e7iVʠ25a(dPpZvu(fƆ.-z\000a!'&
>%זTĂQeeV|{i׮}ƍWdLl\tRS`e=!zm۶%b1I#~qX`cmpS]5|ڲeˡE}F&P7{0
kxf:??(.a4g,\t!UB͛7D(QSȑ#mN</E4x#k8VCg(.O>TVV6k,¾}6!V!s2{S]vB+2
ߏ^i3Bx2!gf=xv͍<i \"ްaIK'NJ,>Dٍtt=3fR&n1]7ʃ!\\.1\"@1ir.R/|زGGUOiG18Q@h2foɵ[>}3dP
}c(zʺ qL
<\\\tZ ༿ܶәI.IK؝L(T~ōm8c\000;5jFtqhM-*gwha8V?2ѼrCH\000B1I[DvvQ|׊ѕ)\$ow]RH !5\000!0_ u_FMvSäQΊ+zDK+a_|AQK'y@y\\̊ɔ:ujNQ&Hq.5&kuVG9:4zl^;z
!dI0 kxe96u:o=CҹXf޽{v\"*;!*Q<:Y&ĜN a=sI/f5PJľoA1sc\"N˒:BˇeNd<@'.CBq\000k̾^c%@JE~!tn.ŜW@xJdJ>{7`E8ya9ҤFO78uLh\"@uJ\\3\\}I۸.\\q- 6?R0f cHr~2fH*9cmf5С-s
cd.3\tDf￿*/P6\" \"!
dkUB8M7483T1*J\"{'M!/IRk@6tO!ڇ-i}UxYE>Chi\t I&>
@~EH\t%9`mTAjj!)48
QU)4O@HFBE\000\"]KN%mdȶ0~@ē}!D'gx DқI<@f6DyY
Kj#iiݭhq-!i]m
=\$ܙa.*/v/Uw/D̀!Ahg_AbL\"P%Ŷ}3g&jr JL)W\000xK'g(S\" >=6\\cA;W6Uw#h\tYwt)
q'?qb3.
\"8qbwϝ;KE}>cpmΰ3xYI,xNͮVby#g3x7@]x9;a@x>/>T{Ulܟu~X'o|[j&bO\000#q~f5
]K&M7u֝\"p|zXO\000gJg-Dǀ\"܉'c;^zHٳ#<pD~1Pb@K>eDBnN21<<9YU(n@\000ΟiP(̿P*vt~cEؿozB% vJ }]iKLqqKW~-Vo\tnDp-Pm@,onUM}aamvM%/cW~G&Z,T]AY?A;,,y@):txG\tM@nrDS ^
ԫERƍP܈Oeb@NtW]X^eJXU[A\000\000Sܜ7̬@o ̸|bිtu37e,.3p]H
3I9o7\t7kFVG-G۷ и\"7r<w&IFNx[\$
%e^*3\\Bp4[-Hisuyr1jR#PYX7{VP<ww@\000ʉMloW\tp\000{P\000YnnKlwfU4HVR8mҚ(DׂxJ&\"\\Btï
Km#%-A\000ll:ි@\000F^`)nHJa(n.s܍L@K?1i`e\t/q@|r'e5tC~WcfY?౮
@}\td{
G2U~s\0000ܙ\000#۞2eȦOV@QoflHB;:>GKD-#~Eюc'wEw9.5PL]kK+MdA9MHEY98F\$rWn&(1\\3BiT7sf+ɂ;Კ 6~l
EWw֥kWsEGlgVS(ǕRČ6{<lDL(X'^ \$2X`@\0001 >_/D\"pYhf(\tK\$y(K/hcཬl0W3g>>Nl8sryv>]\tbUIkZp \$T:/\\0ő[9]Q ʃ:T;EϚ=NoʹȵDJ~Hm_VKB8( sG~EXǳ~w*^y5Yh*~*!
SFq\000綥CCC?Bȵ'RTc|h@\\|-FӼa<_vҘ\000&KA&ݢNjk\$8>\t.]_j.LH\"|goʺȜj%e/wL<UM0<sQtaNq\\}MlZb_fK)@կ9} 
4Fr/5-5ZWXڢ+>*x~ѿ5vןp\ttʲF<,Ym9%T^\000+lD vaPAfEYD0({]
o&5W2,҂Ļ6\$ˣ.YN@/4̩KyUo;w!Bb`D jjhKE!cʫBɓ
ei}(Gn\t&;~~~NI,  9F(NPT\000?jpvk pLTjn󒰘I37f'e#hx\"28fMY[_tYD-)an4 \$FL*Fr]p9hU=-3Am\"6%\\hX62>FrC6B͆?p416}qΨ#t\"{7> w{\\Kr;FFFN< N|6>ʡPF?)PD@#ř@,e VQ!tj]?)6J a߁*!g;XS4IX'gC~rZV^+8uNe%}ײx-gch26:f2_B&Y'O9g20|̩>fb5qR0`s\t/]گo|A_&/xYwA̿S
U:Y.y&-%8Û7u)oߺ[Khj=4bK-lFpѾ좾Pm#ީy0`nNz=*Z OѴ*pF.?á[n=̧94HRI(deY#W侌뮥i,S\tJ^I91*ׁX&.^*fM?Q'A;EQ\000)E\$u
{@m?0ѪXQQ|E}~f(\\0tWD̃}e<\tf\$g}&^1cn\t\\x⥿D7\tx--=eP|a\"+2/|pg<O
R@ALɷ;L^U2DRbz1]=Hݱ@1'Q
5'MT~ȑ/YMj0\"[9|]wjvHXDwoPNZ6Ļć7Aײ #sc
!4\000e3yɘ̲z\tHn##8]A,\000<6n\$̙f
瑳ʢ\\\t:rCe?۶mޱufpi86GbsL*P5XzYm@F])!!.t
Ӱ\tTY,\"!eD
=:!8>\000X
W:o\t1Ne,_~sfu\$fΑlb w7\"-GєXmʁNȿ{H2*=/^TF\$ᩀ4gzz{^I>|\tӹ/jlXsO\"d9o@(Bb*?6sb&Xid\$X+:|tKOӯ9\000j>|kښ^@#ƾ>Wlw΄933UgZb2oZ'􍃨xC*N]SV
I42U4ee>|քz귌@+a@y
1>X\t _9+GԐ\"_\"+kklP~2\"WF؊\$M<H\ttA(,T4[`RsI!5=r^Cd1JA{5@ s%].Ԙqv=\000ӆ\\˰T̕ށ!\0002BP\\h\"梻Y@=GD<9BBM\"ק\"P7 Z
O
A!.%B<-+xt߰Y:G5EnCOT
,Z\"~DċZH}*m۾1\000;ϝ{ML[3b+%(VCBkY(/\t޲n(j\000YrPP+3SRE6^?;v܍EG`._BBB1xe4fyy٣G/1b#C:N9\"oT.]TMHy׸t\\k3@4!
U
%<WwAw >nK9sF>RCbevTT^XSרE,~%\\.Cj]pCT@dЖܺ)(H/X~U(xS\000bczy,#?bGA;7`5HBJ*&  X,,M0[Ð] {/նm\000ܱ\t\000!@Q\twխr6?\tl JB\"fzk\"c_ua\"YI#qOtr/#-܏#I\$I\$6Uɧ\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PluginBundle/Assets/img/generic.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PluginBundle/Assets/img/generic.png", "/var/www/mautic-ktn/app/bundles/PluginBundle/Assets/img/generic.png");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/8b/8b9a56427805fec9021e00a93b403fb9.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PluginBundle/Assets/img/generic.png */
class __TwigTemplate_71080000c6b05399e6c9e33a4b7002d1 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000>a\000\000/IDATx]x^AEz{mbHЋ@@B{DHlIｇF3̖<ٝٙ9;Oeaaaaaaa2Y)9L^tQQpꬒc3NN)>2صχ{Td;V羦_SPWn<2h߅[]IY+\"y_rڬIlIJ㗔dGT!yOʿqI~_eQ-c]Kv\$ǌ\\\\.Nq,ui=\000<8x87o#[:?+\\?t:^Ub+Z^vυ;zqv\\pl#@Wk<Gw[t+c.}eaSYǳ35}vW]|8Nm΅;yNcB*\000֑}Kp'q~'#>Ӹo^Hy[eOo.x,<YS\"L;zrv`^9[`H#hxEwa.4.sn]*x
r?w:<X# m=9=!ʅ\000d qF!\t<A!&W_NY\\eOf]ѻ%ڜwil!\t^@7\000Å1`,DH\0002EWaJ\"M\\DȾ3=~UQ}W0da@3Hqr\t\\=\000F\$i;5[':Ĉ~s\"q-@6Dm\"Wꨴ?iF&~H::|f\tC
cӑ4\$,uA-~8ΐ-DAbPr_G׶'L@Ǵ]#v4<~r_Eb*h䙯O9ܷDޝ)\"]c@^ybf](t5cdmFq3q3a|5#Q\0008\000) .{/qFMJvXϥaGF_BLH>^!ax{ m\"71cWfĎ[\"_?n䠹\\쀹0satNw ^;ăE<΂\000^MVY/o&n~\$t9Ð zؾAw^lVqѣ^wp޳s7s=0}ǹ
N\\Kxp`|)KNZ3-{uɳ\"aꅑOvKOx@VSG,)In*o4/:wN9Ո6=CO`Z7f7jYm[:&g!]x\t7',ޞ6Oz=\"{[R\$\000|Pzln5̷Bmf[uG\$>l!MGuK~=nRHߚ{è|A31q\t}O+q*x_^|?FŇ,qW|ݼ%lT%(0{ʜ-Y=  =N8 \000@>.TѰQ0XgZ4vH4`Cg
Xn7/h'6>:e@kΛ.޼9,܋?`=3TQq5x<Bк~0vCAskXL).jٳg@ϿE\"H0yZ3\000pMBA/ClMy7=D]P0=/9hN\000{MWp\"K


?|&_Eɓ\$N2%aʔ\t'ON:uZU?]4%99]MtH:b
#;
'oܳSDMxPvA멲=疇fc'>/u.|4:۷˔){9::sqť#7p-[3u8s=z2'-粖=]MZ6ݤua<cj!.c}VVM]/ڵƏ/ڵ\tHv֍ԩ3ױήX^}nE>1V׶teD?5g}&
qA(줲,\$k8S0B`\000a?,<Ե vpr&wb;:ٝ\000on\000Bp:rjf\000UE\$D/-SʟFRD:1l,8?ƕSR\\`k}e2N\000r
%N^s#%?F9IA;f͎ppp-\"]\"\000\000\"pp֮]{\"!MGOaDx9.uO']|EeGWRV9t8G3x3q
<svxad;E4\$̙3spwgi{d`\$:<gu)0qM~\"%U5{Ͼs~?~|p߾}ws
%\000AD0rT(i&MX}GLB&L&ڨ佨s(;|Q&kJ.ɫoŧ\$FLL&NXu)z+n-qcǎQUrW#:Ɍ#ՄRY5=+@phF9\000t}ڲ]uoɯg׳gO )~@\\l!1J.SQ[[Bt>I=8)L*94SeǭH.c+T^ăꛭ8t=z\000LX_~x{+1Uff5SYrf:)g_R\000E\000yk|w]v%5\000NM\"A/x3|K+V06ne8hl)FoM]Ʋe.vYTc/8zqk֬٢/p\"\\C W;kӑ=y)FU;\ty)q%@\"`&+7w ċH\000֭ۨp^
gHR]W_?:C:=M|B|K2X/J}tŢ}h %_~wܩ:\\Z<^P@= ׬\t\"Fo
ќJ X;:ڬL֭|sH0.0x;aaa]
El==̑,>av؞*0>2nSؕ3P|\"
X#s\$G#f`X0U\"_I0; ;JtrO&^sr>PYQp>~( r5bDy
|'''\$`t:wv~M܀v4:r;N ƝܿAxA\\i*0>*2tnQXau4T4\\
rJG\tV|]믇%%%U.iQ~ξCr6;4ws2Gt7f\$gJ:*0=ʂ\">Ӵ\"V!+_ʄE&oM˰.;88U,̋Hn{We?@J][P`5988&dYM@s#mWoGGH1`zպ}jEZkoo/iכ899krW}4Pw4YZeG.N}<L
\t\\5/J\"^NڼEٯ<D\000%U#̵a@02%Px<YPH
::}o}3f\$wޝX9D}\000f?%3z3Vԣ*98#lA)G@#4hPSu,ЅR_ HvҤIwvtlll8[[Ζ # A
UYGӏl~j'vR
7
.\$b>M!B(ۦ.o=JZfLttkZe㦀O65fIܐ!C̙:vg;EŚvPA\000̗m8ch,'2܏թfӯS^?dg..*ԩSqeL\000A|poTЕ1;6`NB8w̥-C}'++덕+W^
|g YSYGӎۅK N0<7}bstr 0^Z~\t\000\\@RpX\000(رcUBE=pv:\\e
Zr͆%[?3]^^\" 0+ B6mZ:?RYGӏ>d',lE\000:q<tＹHaA(iG47.`6G\000\\Br{ؚ 킍 %V\$B8!u\"n }1mGsc,UǙMRP&N\$\t߼|rwu4*z;sZųeI<5FR?_;=,}3IM\$9qu~_Ph0%\$v:>owEMgX%Knu&R}wDݫWא.Ca\"GI:իWGɌ̿/XiCR#Z|8T
}\000Dч|&WKZD3]!
o`|Bk'5laBTcD퇸:LCdO&e7ȇ+C`?3i:~*(}=}WдYX܁t\000\000

 H?zY٭/V6m:,AAؼyRYĺIݺ(R@gKf\000+O:w!EDSYw++
;!!aÊ\$|޽{?駟BTp33_O#rdUH+Wسgd.C啴N1GCŤ{BC֕U8f?@
ێ
Et.rrҥL۵k5~]N\000ϟ|X0<
D.w~}f`<xpʴ԰𫯾zjnQy\"Ύ\\|A-C
bκSp*_<?~|V\"\"+\"KȬ^GI58=<ZND[R)t˫e!'pg>oGyv%B|8aX,K@>T;cmz.<Ӭ={߀+%p\000A)hD>8&#r;9gݾ}?Ąg7'L>=.RBfL%K\\)--m7w<U\\*b=voEMRVFMܹs \000hSE6Vr7PFro#l-jժx@
e3A<oBq_jM{B+6ZX\"r
u!Cc?gxxgxF!U(BYEƒL̦+SE5vݹ\${<u\tx\000q֛Jff
Z9{K2@Pu˫=c
6F!u&N\"\$q)'\000nː8(?=z5ǂ%=4#P]Cnnn/9Z\tea//!!y 7\\exzFuCf,&J3Z<q#`&}rai?
.f4\000hV73z}Wn'{mc4pؓЇ\\X'kZ5Ӝ`P[(\"\000B*Z5(,\\%sى0;;<\tڥFtF
ǍDY4n7r|ٵvEJº@փo\$繬69CZ7IpɛHSdMd¾XydVlX*AGCAg>k<!HԩPf^\\.{^3_Fu
x\000-\t-[@>'?wDw\\B2E\000~JM?w9P(deEB47N\0001c0e7iVʠ25a(dPpZvu(fƆ.-z\000a!'&
>%זTĂQeeV|{i׮}ƍWdLl\tRS`e=!zm۶%b1I#~qX`cmpS]5|ڲeˡE}F&P7{0
kxf:??(.a4g,\t!UB͛7D(QSȑ#mN</E4x#k8VCg(.O>TVV6k,¾}6!V!s2{S]vB+2
ߏ^i3Bx2!gf=xv͍<i \"ްaIK'NJ,>Dٍtt=3fR&n1]7ʃ!\\.1\"@1ir.R/|زGGUOiG18Q@h2foɵ[>}3dP
}c(zʺ qL
<\\\tZ ༿ܶәI.IK؝L(T~ōm8c\000;5jFtqhM-*gwha8V?2ѼrCH\000B1I[DvvQ|׊ѕ)\$ow]RH !5\000!0_ u_FMvSäQΊ+zDK+a_|AQK'y@y\\̊ɔ:ujNQ&Hq.5&kuVG9:4zl^;z
!dI0 kxe96u:o=CҹXf޽{v\"*;!*Q<:Y&ĜN a=sI/f5PJľoA1sc\"N˒:BˇeNd<@'.CBq\000k̾^c%@JE~!tn.ŜW@xJdJ>{7`E8ya9ҤFO78uLh\"@uJ\\3\\}I۸.\\q- 6?R0f cHr~2fH*9cmf5С-s
cd.3\tDf￿*/P6\" \"!
dkUB8M7483T1*J\"{'M!/IRk@6tO!ڇ-i}UxYE>Chi\t I&>
@~EH\t%9`mTAjj!)48
QU)4O@HFBE\000\"]KN%mdȶ0~@ē}!D'gx DқI<@f6DyY
Kj#iiݭhq-!i]m
=\$ܙa.*/v/Uw/D̀!Ahg_AbL\"P%Ŷ}3g&jr JL)W\000xK'g(S\" >=6\\cA;W6Uw#h\tYwt)
q'?qb3.
\"8qbwϝ;KE}>cpmΰ3xYI,xNͮVby#g3x7@]x9;a@x>/>T{Ulܟu~X'o|[j&bO\000#q~f5
]K&M7u֝\"p|zXO\000gJg-Dǀ\"܉'c;^zHٳ#<pD~1Pb@K>eDBnN21<<9YU(n@\000ΟiP(̿P*vt~cEؿozB% vJ }]iKLqqKW~-Vo\tnDp-Pm@,onUM}aamvM%/cW~G&Z,T]AY?A;,,y@):txG\tM@nrDS ^
ԫERƍP܈Oeb@NtW]X^eJXU[A\000\000Sܜ7̬@o ̸|bිtu37e,.3p]H
3I9o7\t7kFVG-G۷ и\"7r<w&IFNx[\$
%e^*3\\Bp4[-Hisuyr1jR#PYX7{VP<ww@\000ʉMloW\tp\000{P\000YnnKlwfU4HVR8mҚ(DׂxJ&\"\\Btï
Km#%-A\000ll:ි@\000F^`)nHJa(n.s܍L@K?1i`e\t/q@|r'e5tC~WcfY?౮
@}\td{
G2U~s\0000ܙ\000#۞2eȦOV@QoflHB;:>GKD-#~Eюc'wEw9.5PL]kK+MdA9MHEY98F\$rWn&(1\\3BiT7sf+ɂ;Კ 6~l
EWw֥kWsEGlgVS(ǕRČ6{<lDL(X'^ \$2X`@\0001 >_/D\"pYhf(\tK\$y(K/hcཬl0W3g>>Nl8sryv>]\tbUIkZp \$T:/\\0ő[9]Q ʃ:T;EϚ=NoʹȵDJ~Hm_VKB8( sG~EXǳ~w*^y5Yh*~*!
SFq\000綥CCC?Bȵ'RTc|h@\\|-FӼa<_vҘ\000&KA&ݢNjk\$8>\t.]_j.LH\"|goʺȜj%e/wL<UM0<sQtaNq\\}MlZb_fK)@կ9} 
4Fr/5-5ZWXڢ+>*x~ѿ5vןp\ttʲF<,Ym9%T^\000+lD vaPAfEYD0({]
o&5W2,҂Ļ6\$ˣ.YN@/4̩KyUo;w!Bb`D jjhKE!cʫBɓ
ei}(Gn\t&;~~~NI,  9F(NPT\000?jpvk pLTjn󒰘I37f'e#hx\"28fMY[_tYD-)an4 \$FL*Fr]p9hU=-3Am\"6%\\hX62>FrC6B͆?p416}qΨ#t\"{7> w{\\Kr;FFFN< N|6>ʡPF?)PD@#ř@,e VQ!tj]?)6J a߁*!g;XS4IX'gC~rZV^+8uNe%}ײx-gch26:f2_B&Y'O9g20|̩>fb5qR0`s\t/]گo|A_&/xYwA̿S
U:Y.y&-%8Û7u)oߺ[Khj=4bK-lFpѾ좾Pm#ީy0`nNz=*Z OѴ*pF.?á[n=̧94HRI(deY#W侌뮥i,S\tJ^I91*ׁX&.^*fM?Q'A;EQ\000)E\$u
{@m?0ѪXQQ|E}~f(\\0tWD̃}e<\tf\$g}&^1cn\t\\x⥿D7\tx--=eP|a\"+2/|pg<O
R@ALɷ;L^U2DRbz1]=Hݱ@1'Q
5'MT~ȑ/YMj0\"[9|]wjvHXDwoPNZ6Ļć7Aײ #sc
!4\000e3yɘ̲z\tHn##8]A,\000<6n\$̙f
瑳ʢ\\\t:rCe?۶mޱufpi86GbsL*P5XzYm@F])!!.t
Ӱ\tTY,\"!eD
=:!8>\000X
W:o\t1Ne,_~sfu\$fΑlb w7\"-GєXmʁNȿ{H2*=/^TF\$ᩀ4gzz{^I>|\tӹ/jlXsO\"d9o@(Bb*?6sb&Xid\$X+:|tKOӯ9\000j>|kښ^@#ƾ>Wlw΄933UgZb2oZ'􍃨xC*N]SV
I42U4ee>|քz귌@+a@y
1>X\t _9+GԐ\"_\"+kklP~2\"WF؊\$M<H\ttA(,T4[`RsI!5=r^Cd1JA{5@ s%].Ԙqv=\000ӆ\\˰T̕ށ!\0002BP\\h\"梻Y@=GD<9BBM\"ק\"P7 Z
O
A!.%B<-+xt߰Y:G5EnCOT
,Z\"~DċZH}*m۾1\000;ϝ{ML[3b+%(VCBkY(/\t޲n(j\000YrPP+3SRE6^?;v܍EG`._BBB1xe4fyy٣G/1b#C:N9\"oT.]TMHy׸t\\k3@4!
U
%<WwAw >nK9sF>RCbevTT^XSרE,~%\\.Cj]pCT@dЖܺ)(H/X~U(xS\000bczy,#?bGA;7`5HBJ*&  X,,M0[Ð] {/նm\000ܱ\t\000!@Q\twխr6?\tl JB\"fzk\"c_ua\"YI#qOtr/#-܏#I\$I\$6Uɧ\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PluginBundle/Assets/img/generic.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PluginBundle/Assets/img/generic.png", "/var/www/html/mauticGIT-Test/app/bundles/PluginBundle/Assets/img/generic.png");
    }
}
